@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11430 2019-04-10 05:13:37Z Lavender $
+# $Id: __init__.py 11466 2019-04-17 07:22:28Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-10 13:13:37 +0800 (週三, 10 四月 2019) $
-# $Revision: 11430 $
+# $Date: 2019-04-17 16:22:28 +0900 (週三, 17 四月 2019) $
+# $Revision: 11466 $
 
 from __future__ import print_function
 
@@ -25,7 +25,7 @@ import importlib
 from .Patch import attachURLs, attachDebugURLs
 from .Util import update, populateEnvToSettings
 
-from Iuppiter.DjangoUtil import extendInstalledApps
+from Iuppiter.DjangoUtil import extendInstalledApps, DJANGO_VERSION
 
 # Default SERVER_MODE values.
 DEVELOPMENT = 1
@@ -38,14 +38,6 @@ SERVER_MODES = {
     'PRODUCTION': PRODUCTION,
 }
 
-try:
-    import django
-
-    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
-                      django.VERSION[2])
-except ImportError:
-    warnings.warn("Unable to import django, many Iuno packages require it.")
-
 def createWSGIHandler(cloudLogging=False, settingsModule=None, siteDir=None):
     """
     Create WSGIHandler for django and automatically initialize path settings.
@@ -506,6 +498,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                                     else None),
         'LANGUAGE_CODE': 'en-us',
         'USE_I18N': True,
+        'USE_L10N': True,
+        'USE_TZ': True,
         'LANGUAGES': (
             ('zh-hant', 'Traditional Chinese'),
             ('zh-hans', 'Simplified Chinese'),
@@ -516,6 +510,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         ),
     }
     
+    if (DJANGO_VERSION >= 11100 and 
+        not sys.platform.startswith('win')): # django >= 1.11
+        i18nDefaults['TIME_ZONE'] = 'UTC'
+    
     update(settingsDict, i18nDefaults)
     
     populateEnvToSettings((
@@ -587,9 +585,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'ROOT_URLCONF': '%s.urls' % projectName,
     }
 
-    if warns:
-        warnWithout('ROOT_URLCONF', settingsDict, rootUrlDefaults)
-    
     update(settingsDict, rootUrlDefaults)
     #=========================================================================
     
@@ -615,9 +610,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'WSGI_APPLICATION': '%s.wsgi.application' % projectName,
     }
 
-    if warns:
-        warnWithout('WSGI_APPLICATION', settingsDict, wsgiDefaults)
-    
     update(settingsDict, wsgiDefaults)
     #=========================================================================
 
@@ -663,10 +655,36 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     update(settingsDict, templatesDefaults)
     #=========================================================================
+    
+    #=========================================================================
+    #  AUTH PASSWORD_VALIDATORS
+    authPasswordValidators = {
+        'AUTH_PASSWORD_VALIDATORS': [
+            {
+                'NAME': ('django.contrib.auth.password_validation'
+                         '.UserAttributeSimilarityValidator'),
+            },
+            {
+                'NAME': ('django.contrib.auth.password_validation'
+                         '.MinimumLengthValidator'),
+            },
+            {
+                'NAME': ('django.contrib.auth.password_validation'
+                         '.CommonPasswordValidator'),
+            },
+            {
+                'NAME': ('django.contrib.auth.password_validation'
+                         '.NumericPasswordValidator'),
+            },
+        ]
+    }
+    
+    update(settingsDict, authPasswordValidators)
+    #=========================================================================
 
     #=========================================================================
     # Django plugins.
-    if DJANGO_VERSION >= 210: # django >= 1.11
+    if DJANGO_VERSION >= 11100: # django >= 1.11
         MIDDLEWARE = 'MIDDLEWARE'
     else:
         MIDDLEWARE = 'MIDDLEWARE_CLASSES'
