@@ -4,7 +4,7 @@ echo '#!/bin/bash
 source $HOME/app/bin/activate
 cd /home/nuwa/app/$APP_NAME
 
-{{ command }}
+{{ command|safe|escape }}
 ' > cron/{{ jobName }}
 sed -i -e "s#\$HOME#$HOME#g" cron/{{ jobName }}
 sed -i -e "s#\$PWD#$PWD#g" cron/{{ jobName }}
