@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 11432 2019-04-10 06:04:43Z Lavender $
+# $Id: start_project.py 11464 2019-04-17 06:34:50Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-10 14:04:43 +0800 (週三, 10 四月 2019) $
-# $Revision: 11432 $
+# $Date: 2019-04-17 15:34:50 +0900 (週三, 17 四月 2019) $
+# $Revision: 11464 $
 
 import os
 import sys
@@ -24,6 +24,7 @@ from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
 from django.template import Context
 
+from Iuno.Version import IUNO_VERSION
 from Iuppiter.Encoding import utf8
 
 
@@ -71,14 +72,12 @@ class Command(BaseCommand):
         def renderFile(template, path, fileName, linux=False):
             temp = get_template(template)
             
-            if six.PY3:
-                context = {
-                    "useConda": True,
-                }
-            else:
-                context = {
-                    "useConda": False,
-                }
+            context = {
+                "name": name,
+                "useConda": False,
+                "version": IUNO_VERSION,
+                "envName": os.environ.get("CONDA_DEFAULT_ENV", "%s_ENV" % name),
+            }
                 
             content = temp.render(context)
 
@@ -93,8 +92,7 @@ class Command(BaseCommand):
                     f.write(content)
 
         # file -----------------------------------------------------------------
-        if not six.PY3:
-            renderFile('scaffold/Activate.bat', path, 'Activate.bat')
+        renderFile('scaffold/Activate.bat', path, 'ActivateEnv.bat')
         renderFile('scaffold/Configure.bat', path, 'Configure.bat')
         renderFile('scaffold/Configure.sh', path, 'Configure.sh', linux=True)
         renderFile('scaffold/README.txt', path, 'README.txt')
@@ -163,7 +161,30 @@ class Command(BaseCommand):
         temp = get_template('scaffold/TimeZone.py')
         timeZone = temp.render()
         content = content.replace(timeZone, '')
-
+        
+        # template & middleware & auth password
+        temp = get_template('scaffold/Templates.py')
+        templates = temp.render()
+        content = content.replace(templates, '')
+        
+        temp = get_template('scaffold/Middleware.py')
+        middleware = temp.render()
+        content = content.replace(middleware, '')
+        
+        temp = get_template('scaffold/Auth.py')
+        auth = temp.render()
+        content = content.replace(auth, '')
+        
+        # wsgi & root urlconf
+        temp = get_template('scaffold/Wsgi.py')
+        wsgi = temp.render(context)
+        content = content.replace(wsgi, '')
+        
+        temp = get_template('scaffold/Urlconf.py')
+        urlconf = temp.render(context)
+        content = content.replace(urlconf, '')
+        
+        
         # Footer
         temp = get_template('scaffold/FooterTemplate.py')
         footer = temp.render()
