@@ -1,21 +1,12 @@
 #!/bin/sh
 
-{% if useConda %}
-if [ -z $VIRTUAL_ENV ]; then
-    python -m pip install --upgrade pip
-    pip install -r REQUIREMENTS.txt
-fi
-{% else %}
-if [ -z $VIRTUAL_ENV ]; then
-    virtualenv env
+if [ -z $CONDA_DEFAULT_ENV ]; then
+    conda create -p env python=3.6.8 -y
     source env/bin/activate
     python -m pip install --upgrade pip
     pip install -r REQUIREMENTS.txt
 fi
 
-: ${VIRTUAL_ENV:?"You must run inside virtualenv."}
-{% endif %}
-
 python manage.py migrate --noinput
 if [[ $? -ne 0 ]] ; then
     # Unknown why (not investigate yet), MySQL will complain foreign key 
