@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettingsTest.py 11430 2019-04-10 05:13:37Z Lavender $
+# $Id: AttachSettingsTest.py 11459 2019-04-16 18:20:57Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-10 13:13:37 +0800 (週三, 10 四月 2019) $
-# $Revision: 11430 $
+# $Date: 2019-04-17 03:20:57 +0900 (週三, 17 四月 2019) $
+# $Revision: 11459 $
 
 import os
 import warnings
@@ -25,10 +25,7 @@ from Iuno import member
 BASE_DIR = '.'
 
 try:
-    import django
-
-    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
-                      django.VERSION[2])
+    from Iuppiter.DjangoUtil import DJANGO_VERSION
                       
     if DJANGO_VERSION >= 210: # django >= 1.11
         MIDDLEWARE = 'MIDDLEWARE'
